import Model from '../Model';
import * as Types from './Types';
import * as Relations from './Relations';
export declare type Entity = typeof Model | string;
export declare type Field = Fields | Types.Type | Relations.Relation;
export declare type Attribute = Types.Type | Relations.Relation;
export interface Fields {
    [key: string]: Field;
}
export default class Attributes {
    /**
     * The generic attribute. The given value will be used as default value
     * of the property when instantiating a model.
     */
    static attr(value: any, mutator?: (value: any) => any): Types.Attr;
    /**
     * The has one relationship.
     */
    static hasOne(model: Entity, foreignKey: string): Relations.HasOne;
    /**
     * The belongs to relationship.
     */
    static belongsTo(model: Entity, foreignKey: string): Relations.BelongsTo;
    /**
     * The has many relationship.
     */
    static hasMany(model: Entity, foreignKey: string): Relations.HasMany;
    /**
     * The has many by relationship.
     */
    static hasManyBy(model: Entity, foreignKey: string, otherKey?: string): Relations.HasManyBy;
    /**
     * Determine if the given value is the type of field.
     */
    static isAttribute(attr: Field): attr is Attribute;
    /**
     * Determine if the given value is the type of fields.
     */
    static isFields(attr: Field): attr is Fields;
}
