"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AttrTypes_1 = require("./AttrTypes");
var Attributes = /** @class */ (function () {
    function Attributes() {
    }
    /**
     * The generic attribute. The given value will be used as default value
     * of the property when instantiating a model.
     */
    Attributes.attr = function (value, mutator) {
        return { type: AttrTypes_1.default.Attr, value: value, mutator: mutator };
    };
    /**
     * The has one relationship.
     */
    Attributes.hasOne = function (model, foreignKey) {
        return { type: AttrTypes_1.default.HasOne, model: model, foreignKey: foreignKey, value: null };
    };
    /**
     * The belongs to relationship.
     */
    Attributes.belongsTo = function (model, foreignKey) {
        return { type: AttrTypes_1.default.BelongsTo, model: model, foreignKey: foreignKey, value: null };
    };
    /**
     * The has many relationship.
     */
    Attributes.hasMany = function (model, foreignKey) {
        return { type: AttrTypes_1.default.HasMany, model: model, foreignKey: foreignKey, value: null };
    };
    /**
     * The has many by relationship.
     */
    Attributes.hasManyBy = function (model, foreignKey, otherKey) {
        if (otherKey === void 0) { otherKey = 'id'; }
        return { type: AttrTypes_1.default.HasManyBy, model: model, foreignKey: foreignKey, otherKey: otherKey, value: null };
    };
    /**
     * Determine if the given value is the type of field.
     */
    Attributes.isAttribute = function (attr) {
        if (this.isFields(attr)) {
            return false;
        }
        return attr.type === AttrTypes_1.default.Attr
            || attr.type === AttrTypes_1.default.HasOne
            || attr.type === AttrTypes_1.default.BelongsTo
            || attr.type === AttrTypes_1.default.HasMany
            || attr.type === AttrTypes_1.default.HasManyBy;
    };
    /**
     * Determine if the given value is the type of fields.
     */
    Attributes.isFields = function (attr) {
        return attr.type === undefined;
    };
    return Attributes;
}());
exports.default = Attributes;
//# sourceMappingURL=index.js.map