"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("./support/lodash");
var rootGetters_1 = require("./modules/rootGetters");
var rootActions_1 = require("./modules/rootActions");
var mutations_1 = require("./modules/mutations");
var subGetters_1 = require("./modules/subGetters");
var subActions_1 = require("./modules/subActions");
var Module = /** @class */ (function () {
    function Module() {
    }
    /**
     * Creates module from the given entities.
     */
    Module.create = function (namespace, entities) {
        var tree = {
            namespaced: true,
            state: { name: namespace },
            getters: rootGetters_1.default,
            actions: rootActions_1.default,
            mutations: mutations_1.default,
            modules: {}
        };
        return this.createTree(tree, namespace, entities);
    };
    /**
     * Creates module tree to be registered under top level module
     * from the given entities.
     */
    Module.createTree = function (tree, namespace, entities) {
        var _this = this;
        _.forEach(entities, function (entity) {
            tree.getters[entity.model.entity] = function (_state, getters) { return function (wrap) {
                if (wrap === void 0) { wrap = true; }
                return getters.query(entity.model.entity, wrap);
            }; };
            tree.modules[entity.model.entity] = {
                namespaced: true,
                state: __assign({}, entity.module.state, _this.state, { $connection: namespace, $name: entity.model.entity, $primaryKey: entity.model.primaryKey })
            };
            tree.modules[entity.model.entity]['getters'] = __assign({}, subGetters_1.default, entity.module.getters);
            tree.modules[entity.model.entity]['actions'] = __assign({}, subActions_1.default, entity.module.actions);
            tree.modules[entity.model.entity]['mutations'] = entity.module.mutations || {};
        });
        return tree;
    };
    /**
     * The default state. This state will be merged with additional
     * entity's state if it has any.
     */
    Module.state = {
        $connection: '',
        $name: '',
        $primaryKey: '',
        data: {}
    };
    return Module;
}());
exports.default = Module;
//# sourceMappingURL=Module.js.map