"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Repo_1 = require("../Repo");
exports.default = {
    /**
     * Save the given data to the state. This will replace any existing
     * data in the state.
     */
    create: function (state, _a) {
        var entity = _a.entity, data = _a.data;
        Repo_1.default.create(state, entity, data);
    },
    /**
     * Insert given data to the state. Unlike `create`, this method will not
     * remove existing data within the state, but it will update the data
     * with the same primary key.
     */
    insert: function (state, _a) {
        var entity = _a.entity, data = _a.data;
        Repo_1.default.insert(state, entity, data);
    },
    /**
     * Update data in the store.
     */
    update: function (state, _a) {
        var entity = _a.entity, data = _a.data, _b = _a.where, where = _b === void 0 ? undefined : _b;
        Repo_1.default.update(state, entity, data, where);
    },
    /**
     * Delete data from the store.
     */
    delete: function (state, _a) {
        var entity = _a.entity, where = _a.where;
        Repo_1.default.delete(state, entity, where);
    },
    /**
     * Delete all data from the store.
     *
     * @param {object} payload If exists, it should contain `entity`.
     */
    deleteAll: function (state, payload) {
        if (payload && payload.entity) {
            Repo_1.default.deleteAll(state, payload.entity);
            return;
        }
        Repo_1.default.deleteAll(state);
    }
};
//# sourceMappingURL=mutations.js.map