"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    /**
     * Save the given data to the state. This will replace any existing
     * data in the state.
     */
    create: function (_a, _b) {
        var commit = _a.commit;
        var entity = _b.entity, data = _b.data;
        commit('create', { entity: entity, data: data });
    },
    /**
     * Insert given data to the state. Unlike `create`, this method will not
     * remove existing data within the state, but it will update the data
     * with the same primary key.
     */
    insert: function (_a, _b) {
        var commit = _a.commit;
        var entity = _b.entity, data = _b.data;
        commit('insert', { entity: entity, data: data });
    },
    /**
     * Update data in the store.
     */
    update: function (_a, _b) {
        var commit = _a.commit;
        var entity = _b.entity, where = _b.where, data = _b.data;
        commit('update', { entity: entity, where: where, data: data });
    },
    /**
     * Delete data from the store.
     */
    delete: function (_a, _b) {
        var commit = _a.commit;
        var entity = _b.entity, where = _b.where;
        commit('delete', { entity: entity, where: where });
    },
    /**
     * Delete all data from the store.
     *
     * @param {object} payload If exists, it should contain `entity`.
     */
    deleteAll: function (_a, payload) {
        var commit = _a.commit;
        commit('deleteAll', payload);
    }
};
//# sourceMappingURL=rootActions.js.map