"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    /**
     * Save the given data to the state. This will replace any existing
     * data in the state.
     */
    create: function (_a, _b) {
        var commit = _a.commit, state = _a.state;
        var data = _b.data;
        commit(state.$connection + "/create", { entity: state.$name, data: data }, { root: true });
    },
    /**
     * Insert given data to the state. Unlike `create`, this method will not
     * remove existing data within the state, but it will update the data
     * with the same primary key.
     */
    insert: function (_a, _b) {
        var commit = _a.commit, state = _a.state;
        var data = _b.data;
        commit(state.$connection + "/insert", { entity: state.$name, data: data }, { root: true });
    },
    /**
     * Update data in the store.
     */
    update: function (_a, payload) {
        var commit = _a.commit, state = _a.state;
        var where = payload.where;
        var data = payload.data;
        if (where === undefined || data === undefined) {
            commit(state.$connection + "/update", { entity: state.$name, data: payload }, { root: true });
            return;
        }
        commit(state.$connection + "/update", { entity: state.$name, where: where, data: data }, { root: true });
    },
    /**
     * Delete data from the store.
     */
    delete: function (_a, condition) {
        var commit = _a.commit, state = _a.state;
        commit(state.$connection + "/delete", {
            entity: state.$name,
            where: typeof condition === 'object' ? condition.where : condition
        }, { root: true });
    },
    /**
     * Delete all data from the store.
     */
    deleteAll: function (_a) {
        var commit = _a.commit, state = _a.state;
        commit(state.$connection + "/deleteAll", {
            entity: state.$name
        }, { root: true });
    }
};
//# sourceMappingURL=subActions.js.map